@@ -1,4 +1,4 @@
-"""This piece of software was last updated on 28-April-2021 at 20:45 IST.
+"""This piece of software was last updated on 04-May-2021 at 10:06 IST.
 Pull requests are always welcomed"""
 
 from pywhatkit.ascii_art import image_to_ascii_art
@@ -6,7 +6,7 @@ from pywhatkit.chr_to_handwriting import text_to_handwriting
 import pywhatkit.help
 from pywhatkit.main import print_sleep_time, check_window, sendwhatmsg, sendwhatmsg_to_group, sendwhatmsg_instantly, info, playonyt, search
 from pywhatkit.sc import shutdown, cancelShutdown
-from pywhatkit.wwd import tutorial_english, tutorial_hindi, developer_contact
+from pywhatkit.wwd import tutorial_english, tutorial_hindi, developer_contact, join_discord
 from pywhatkit.history import showHistory
-
+from pywhatkit.mail import send_mail
 
