@@ -1,5 +1,5 @@
-def showHistory():
-    """Prints the information of all last sent messages using this program"""
+def showHistory() -> None:
+    """Prints the information of all the sent messages using this program"""
     with open("pywhatkit_dbs.txt","r") as f:
         content = f.read()
 
